
local SheepAddition = ...

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    SheepAddition:log("Hello World: game version < 1.6")
    return
end
SheepAddition:log("Hello World: game version " .. foundation.getGameVersion())

function checkVersion(_name, _id, _minimalVersion)
        if (foundation.getModVersion == nil) then
            SheepAddition:msgBox("SheepAddition: Unknown mod version")
            return false
        end
        if not foundation.isModEnabled(_id) then
            SheepAddition:msgBox("SheepAddition: " .. _name .. " disabled")
            return false
        end
        if not foundation.isModLoaded(_id) then
            SheepAddition:msgBox("SheepAddition: Up the position of " .. _name .. " in the mod list of your game")
            return false
        end
        local _myVersion = foundation.getModVersion(_id)
        SheepAddition:msgBox("SheepAddition: " .. _name .. " Current version : " .. _myVersion)
        if version.cmp(_myVersion, _minimalVersion) < 0 then
            SheepAddition:msgBox("SheepAddition: Please, load the last version of " .. _name)
            return false
        end
        return true
end

if not checkVersion("Common Resources", "76daffe0-725f-4dac-b1b5-de331dfca67a", "1.1.1") then
    return
end

if foundation.isModLoaded("debb69c1-eb38-4183-9739-fbafa47568b4") then -- "Livestock Farms" already loaded
   SheepAddition:msgBox("SheepAddition: Up the position of "Sheep Addition V5" in the mod list of your game right after "Common Resource")
   return
end

    -- Apply building asset processor
    SheepAddition:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    -- Register core prefab nodes (currently only one core model)
    SheepAddition:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", SheepAdditionPrefix .. "_CORE_BUILDING_PREFAB")

    -- Register the sheep dairy Core building part
    SheepAddition:register({
	DataType = "BUILDING_PART",
	Id = SheepAdditionPrefix .. "_CORE_BUILDING_PART",
	Name = SheepAdditionPrefix .. "_CORE_BUILDING_NAME",
	Description = SheepAdditionPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = SheepAdditionPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
    })

SheepAddition:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")

SheepAddition:register({
    Id = SheepAdditionPrefix .. "_MONUMENT",
    DataType = "BUILDING",
    AssetCoreBuildingPart = SheepAdditionPrefix .. "_CORE_BUILDING_PART",
    Name = SheepAdditionPrefix .. "_MONUMENT_NAME",
    Description = SheepAdditionPrefix .. "_MONUMENT_DESC",
    BuildingType = "GENERAL",
    BuildingPartSetList = {
		{
			Name = SheepAdditionPrefix .. "_PARTSETLIST_NAME",
                	BuildingPartList = { 
                            SheepAdditionPrefix .. "_MAIN_PART",
                            SheepAdditionPrefix .. "_CHEESE_SIGN_PART"
                        }
                }
    },
    RequiredPartList = {
		-- Necessarily a list of 'MONUMENT_REQUIRED_PART_PAIR', no need to specify the DataType of each element of the list
		{ Category = "CORE", Quantity = 1 }
    },
    IsEditable = true
})

-- Job: SheepAdditionPrefix .. "_SLAUGHTER" -------------------------------------------------------------------------------------
SheepAddition:register({
	DataType = "JOB",
	Id = SheepAdditionPrefix .. "_SLAUGHTER",
	JobName = SheepAdditionPrefix .. "_SLAUGHTER_NAME",
	JobDescription = SheepAdditionPrefix .. "_SLAUGHTER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
        ProductionDelay = 70.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_SHEPHERD_STICK"
		},
		IdleAnimation = "GUARD"
	}
})

SheepAddition:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        SheepAdditionPrefix .. "_SLAUGHTER"
    }
})

SheepAddition:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        SheepAdditionPrefix .. "_SLAUGHTER"
    }
})

SheepAddition:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        SheepAdditionPrefix .. "_SLAUGHTER"
    }
})

SheepAddition:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = SheepAdditionPrefix .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = SheepAdditionPrefix .. "_FUNCTION_LIST"
})

SheepAddition:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = SheepAdditionPrefix .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        SheepAdditionPrefix .. "_MILK_FUNCTION",
                        SheepAdditionPrefix .. "_CHEESE_FUNCTION",
                        SheepAdditionPrefix .. "_MUTTON_FUNCTION",
                        "BUILDING_FUNCTION_SHEEP_FARM"
                }
})

SheepAddition:registerAssetId("models/sheepAddition.fbx/Prefab/sheepAddition/sheepAdditionPart", SheepAdditionPrefix .. "_MAIN_PREFAB")

SheepAddition:register({
	DataType = "BUILDING_PART",
	Id = SheepAdditionPrefix .. "_MAIN_PART",
	Name = SheepAdditionPrefix .. "_MAIN_NAME",
	Description = SheepAdditionPrefix .. "_MAIN_DESC",
	Category = "CORE",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 5.4, 6 }, { 0, -2.75 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = SheepAdditionPrefix .. "_MAIN_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		},
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	AssetBuildingFunction = SheepAdditionPrefix .. "_ASSIGNABLE_FUNCTION"
})

SheepAddition:register({
		DataType = "BUILDING_FUNCTION_LIVESTOCK_FARM",
                Id = SheepAdditionPrefix .. "_MILK_FUNCTION",
                Name = SheepAdditionPrefix .. "_MILK_FUNCTION_NAME",
		WorkerCapacity = 3,
		RelatedJob = { 
			Job = "SHEPHERD",
			Behavior = "BEHAVIOR_WORK"
		},
		ResourceProduced = {
			{ Resource = "MILK", Quantity = 1 }
		},
                SpawningLivestock = "PREFAB_LIVESTOCK_SHEEP",
                SpawnLivestockButtonText = SheepAdditionPrefix .. "_SHEEP_SPAWN_TEXT",
                RemoveLivestockButtonText = SheepAdditionPrefix .. "_SHEEP_REMOVE_TEXT"
})

SheepAddition:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = SheepAdditionPrefix .. "_CHEESE_FUNCTION",
                Name = SheepAdditionPrefix .. "_CHEESE_FUNCTION_NAME",
		WorkerCapacity = 2,
                RelatedJob = { Job = "CHEESE_MAKER", Behavior = "BEHAVIOR_WORK" },
                InputInventoryCapacity = {
			{ Resource = "MILK", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "MILK", Quantity = 5 }
                },
                ResourceProduced = {
			{ Resource = "CHEESE", Quantity = 1 }
                }
})

SheepAddition:register({
		DataType = "BUILDING_FUNCTION_LIVESTOCK_FARM",
                Id = SheepAdditionPrefix .. "_MUTTON_FUNCTION",
                Name = SheepAdditionPrefix .. "_MUTTON_FUNCTION_NAME",
		WorkerCapacity = 1,
		RelatedJob = { 
			Job = SheepAdditionPrefix .. "_SLAUGHTER",
			Behavior = "BEHAVIOR_WORK"
		},
		ResourceProduced = {
			{ Resource = "BV1_CARCASS", Quantity = 1 }
		},
                SpawningLivestock = "PREFAB_LIVESTOCK_SHEEP",
                SpawnLivestockButtonText = SheepAdditionPrefix .. "_SHEEP_SPAWN_TEXT",
                RemoveLivestockButtonText = SheepAdditionPrefix .. "_SHEEP_REMOVE_TEXT"
})

SheepAddition:registerPrefabComponent("models/sheepAddition.fbx/Prefab/sheepAddition/sheepAdditionPart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = {5.4, 1}
})

SheepAddition:registerAssetId("models/sheepAddition.fbx/Prefab/sheepAddition/cheeseSignPart", SheepAdditionPrefix .. "_CHEESE_SIGN_PREFAB")

SheepAddition:register({
	DataType = "BUILDING_PART",
	Id = SheepAdditionPrefix .. "_CHEESE_SIGN_PART",
	Name = SheepAdditionPrefix .. "_CHEESE_SIGN_NAME",
	Description = SheepAdditionPrefix .. "_CHEESE_SIGN_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = SheepAdditionPrefix .. "_CHEESE_SIGN_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})

SheepAddition:registerPrefabComponent("models/sheepAddition.fbx/Prefab/sheepAddition/cheeseSignPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR"
})
